=======
Credits
=======

Development Lead
----------------

* Dave Dittrich <dave.dittrich@gmail.com>

Contributors
------------

None yet. Why not be the first?

Support
-------

Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-pypackage`_

Development of this program was supported in part under an Open Source
Development Grant from the Comcast Innovation Fund.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
